Raw numeric Non-XBRL — Calcbench API Client documentation

# Raw numeric Non-XBRL

Numbers extracted from non-XBRL sections of 10-K/Q, earnings press-releases and 8-K

class calcbench.raw_numeric_non_XBRL.NonXBRLFact(**kwargs)

  Cooresponds to NonXBRLFact on the server

  CIK: str
  UOM: str
  Value: float
  XBRLfilingID: int
  column_label: str
  companyID: int
  document: str
  entity_name: str
  extract_tag: str
  fact_id: int
  filingID: int
  filing_date: datetime.datetime
  filing_end_date: datetime.datetime
  filing_period: calcbench.api_query_params.Period
  filing_year: int
  fiscal_period: calcbench.api_query_params.Period
  fiscal_year: int
  is_guidance: bool
  is_non_gaap: bool
  label: str
  metric: str
  metric_id: int
  range_high: bool
  range_low: bool
  sec_filing_URL: str
  sec_html_url: str
  special_fact_type: str
  statement_type: int
  tabular_item: bool
  ticker: str

calcbench.raw_numeric_non_XBRL.non_XBRL_numeric(company_identifiers=[], entire_universe=False, clauses=[])

  Data frame of non-XBRL numbers.

  Data behind https://www.calcbench.com/pressReleaseRaw. A professional Calcbench subscription is required to access this data.

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - entire_universe (`bool`) – Search all companies

    - clauses (`Sequence`[`RawDataClause`]) – See the parameters that can be passed @ https://www.calcbench.com/api/rawDataNonXBRLPoints

  Usage:

        >>> clauses = [
        >>>    {"parameter": "fiscalYear", "operator": 1, "value": 2019},
        >>> ]
        >>> d = cb.non_XBRL_numeric(company_identifiers=['MSFT'], clauses=clauses)

  Return type

    `DataFrame`

calcbench.raw_numeric_non_XBRL.non_XBRL_numeric_raw(company_identifiers, entire_universe=False, clauses=[])

  Non-XBRL numbers extracted from a variety of SEC filings, mainly earnings press-releases

  The data behind https://www.calcbench.com/nonXBRLRawData.

  A professional Calcbench subscription is required to access this data.

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – list of tickers or CIK codes

    - entire_universe (`bool`) – Search all companies

    - clauses (`Sequence`[`RawDataClause`]) – See the parameters that can be passed @ https://www.calcbench.com/api/rawDataNonXBRLPoints

  Usage:

        >>> clauses = [
        >>>     {
        >>>         "value": single_date.strftime("%Y-%m-%d"),
        >>>          "parameter": "filingDate",
        >>>         "operator": 1,
        >>>     },
        >>>     {"value": 2021, "parameter": "calendarYear", "operator": 1},
        >>>     {"value": "1Q", "parameter": "calendarPeriod", "operator": 1},
        >>> ]
        >>> d2 = list(cb.non_XBRL_numeric_raw(entire_universe=True, clauses=clauses))

  Return type

    `Generator`[`NonXBRLFact`, `None`, `None`]